/*
    <one line to give the program's name and a brief idea of what it does.>
    Copyright (C) <year>  <name of author>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/

#ifndef QGISMTLEGEND_H
#define QGISMTLEGEND_H

#include <qgslegendinterface.h>
#include <QTreeWidget>
#include <qgslegendlayer.h>
#include <qgslegenditem.h>
#include <qgslegendgroup.h>
#include <qgsmapcanvas.h>
#include <qgisinterface.h>

#include "minifingercount.h"

class QGisMTLegend : public QTreeWidget
{
Q_OBJECT
    

public:
    QGisMTLegend(QgsMapCanvas* mapcanvas,QgisInterface *mIface,QWidget *parent=0, const char* name=0);
    virtual ~QGisMTLegend();
    virtual QList< QgsMapLayer* > layers() const;
    virtual QStringList groups();

    /** Returns QgsLegendLayer associated with current layer */
    virtual QgsLegendLayer* currentLegendLayer();

    /*!Returns the current layer if the current item is a QgsLegendLayer.
    If the current item is a QgsLegendLayer, its first maplayer is returned.
    Else, 0 is returned.*/
    virtual QgsMapLayer* currentLayer();

    /*!set the current layer
    returns true if the layer exists, false otherwise*/
    virtual bool setCurrentLayer( QgsMapLayer *layer );

    /**Updates layer set of map canvas*/
    virtual void updateMapCanvasLayerSet();
    
    virtual void setVisible(bool visible);


  protected:
    MiniFingerCount* miniFC ;
    BlobFingerCount* blob;
    int currentNbFinger;
    
    MiniFingerCount* miniFCExtend ;
    BlobFingerCount* blobExtend;
    int currentNbFingerExtend;
    
    QgsMapCanvas* canvas;
    QList<QgsMapCanvasLayer*> canvasLayer;
    QgisInterface* iface;
    QgsLegendInterface *legIface;
    
    virtual void initMiniFC();
    

    virtual QgsLegendLayer* findLegendLayer(const QString& layerkey);
    virtual QgsLegendLayer* findLegendLayer(const QgsMapLayer * layer);
    /**Returns the first item in the hierarchy*/
    virtual QTreeWidgetItem* firstItem();

    /**Returns the next item (next sibling or next item on level above)*/
    virtual QTreeWidgetItem* nextItem( QTreeWidgetItem* item );

    /**Returns the next sibling of an item or 0 if there is none*/
    virtual QTreeWidgetItem* nextSibling( QTreeWidgetItem* item );

    /**Returns the previous sibling of an item or 0 if there is none*/
    virtual QTreeWidgetItem* previousSibling( QTreeWidgetItem* item );
    
    virtual void hideMiniFCExtended();
    virtual void showMiniFCExtended();
    
public slots:
    //Begin QgisLegendInterface
    virtual void refreshLayerSymbology(QgsMapLayer* ml);
    virtual void refreshLayerSymbology(QString key);
    virtual void setLayerVisible(QgsMapLayer* ml, bool visible);
    virtual void setGroupVisible(int groupIndex, bool visible);
    virtual void setGroupExpanded(int groupIndex, bool expand);
    virtual void moveLayer(QgsMapLayer* ml, int groupIndex);
    virtual void removeGroup(int groupIndex);
    virtual int addGroup(QString name, bool expand = true);
    virtual bool isLayerVisible(QgsMapLayer* ml);
    virtual bool isGroupVisible(int groupIndex);
    virtual bool isGroupExpanded(int groupIndex);
    virtual bool groupExists(int groupIndex);
    //End QgisLegendInterface
    virtual void addLayer(QgsMapLayer* layer);
    
    virtual void selectLayer(int nbF);
    virtual void selectLayer();
    virtual void selectNextLayer();
    virtual void selectPreviousLayer();
    
    
protected slots:
    /** delegates current layer to map canvas */
    void handleCurrentItemChanged( QTreeWidgetItem* current, QTreeWidgetItem* previous );
    virtual void updateCurrentNbFinger(int nbF);
    virtual void updateCurrentNbFingerExtend(int nbF){ currentNbFingerExtend = nbF;}

signals:
  void itemMoved( QModelIndex oldIndex, QModelIndex newIndex );

  void zOrderChanged();

  //! Emited whenever current (selected) layer changes
  //  the pointer to layer can be null if no layer is selected
  //void currentLayerChanged( QgsMapLayer * layer );
  void currentLayerChanged( QString * layerKey );
};

#endif // QGISMTLEGEND_H
