#include "qgismttoolzoom.h"
#include <QRectF>
#include <QPointF>

QGisMTToolZoom::QGisMTToolZoom(QgsMapCanvas* canvas) :
    QGisMTTool(canvas)
{
}

void QGisMTToolZoom::toolAction(const QLine &l1, const QLine &l2) {
    double scale;
    if (toolMode == IDLE) {
        zoomMat.reset();
        my_canvas->freeze(true);
        scale = 1;
        activate();
    }
    else {
        scale = (dist(l1.p2(),l2.p2())/dist(pL,pR));
    }

    QRectF rect = my_canvas->QGraphicsView::sceneRect();

    QPointF center = rect.center();

    zoomMat.scale(scale,scale);
    setPR(l2.p2());
    setPL(l1.p2());
    my_canvas->setTransform(zoomMat);
    my_canvas->centerOn(center);

    qDebug() << "Scale : " << scale ;
    my_canvas->setDirty(true);
}


void QGisMTToolZoom::toolActionEnd() {
    qDebug() << __PRETTY_FUNCTION__;
    my_canvas->freeze(false);
    my_canvas->setTransform(QTransform::QTransform());
    my_canvas->zoomByFactor(1/zoomMat.m11());
    my_canvas->refresh();
    my_canvas->updateOverview();
    zoomMat.reset();
    idle();
}


float QGisMTToolZoom::dist(QPoint p1, QPoint p2)
{
  float res = ((float)p1.x() - (float)p2.x())*((float)p1.x() - (float)p2.x()) + ((float)p1.y() - (float)p2.y())*((float)p1.y() - (float)p2.y()) ;
  return ::sqrt(res);
}


#ifdef USECMAKE
#include "qgismttoolzoom.moc"
#endif
