#include "testqtuio.h"


#include <QApplication>
#include <QEvent>
#include <QMouseEvent>
#include <QtGui/QLabel>
#include <QtGui/QMenu>
#include <QtGui/QMenuBar>
#include <QtGui/QAction>


testqtuio::testqtuio()
{
    setAttribute(Qt::WA_AcceptTouchEvents);
    QLabel* l = new QLabel( this );
    l->setText( "Hello World!" );
    setCentralWidget( l );
    QAction* a = new QAction(this);
    a->setText( "Quit" );
    connect(a, SIGNAL(triggered()), SLOT(close()) );
    menuBar()->addMenu( "File" )->addAction( a );
    tuio.start();
}

bool testqtuio::event(QEvent* e)
{
    if (e->type()==QEvent::MouseButtonPress) {
        QMouseEvent* me = dynamic_cast<QMouseEvent*>(e);
        qDebug()<<"mouse press button" << me->buttons();
        return false;
    }
    if (e->type()==QEvent::MouseMove) {
      QMouseEvent* me = dynamic_cast<QMouseEvent*>(e);
      qDebug()<<"mouse move button" << me->buttons();
      return false;
    }
    if (e->type()==QEvent::MouseButtonRelease) {
      QMouseEvent* me = dynamic_cast<QMouseEvent*>(e);
      qDebug()<<"mouse release button" << me->buttons();
      return false;
    }
    if (e->type() == QEvent::TouchBegin) {
        QTouchEvent *te = dynamic_cast<QTouchEvent* >(e);
        touchBegin(te);
        qDebug()<<"touch begin";
        update();
        return true;

    } else if (e->type() == QEvent::TouchUpdate) {
        QTouchEvent *te = dynamic_cast<QTouchEvent* >(e);
        qDebug()<<"touch update";
        touchUpdate(te);
        update();
        return true;

    } else if (e->type() == QEvent::TouchEnd) {
        QTouchEvent *te = dynamic_cast<QTouchEvent* >(e);
        qDebug()<<"touch update";
        touchEnd(te);
        update();
        return true;
    }
    return QWidget::event(e);

}

void testqtuio::touchBegin(QTouchEvent* e)
{
    QList<QTouchEvent::TouchPoint> points = e->touchPoints();
    QPoint bary = barycenter(points);
    QMouseEvent* panevent = new QMouseEvent(QEvent::MouseButtonPress,bary,Qt::MidButton,Qt::MidButton,Qt::NoModifier);
    QApplication::postEvent(this,panevent);
}
void testqtuio::touchEnd(QTouchEvent* e)
{
  QList<QTouchEvent::TouchPoint> points = e->touchPoints();
  QPoint bary = barycenter(points);
  QMouseEvent* panevent = new QMouseEvent(QEvent::MouseButtonRelease,bary,Qt::MidButton,Qt::MidButton,Qt::NoModifier);
  QApplication::postEvent(this,panevent);
}

void testqtuio::touchUpdate(QTouchEvent* e)
{
  QList<QTouchEvent::TouchPoint> points = e->touchPoints();
  QPoint bary = barycenter(points);
  QMouseEvent* panevent = new QMouseEvent(QEvent::MouseMove,bary,Qt::MidButton,Qt::MidButton,Qt::NoModifier);
  QApplication::postEvent(this,panevent);
}

QPoint testqtuio::barycenter(QList< QTouchEvent::TouchPoint > points)
{
  QPointF res;
  for(int i=0; i<points.size();i++)
  {
    res += points.at(i).pos()+this->pos();
  }
  if(points.size()!=0)
  {
    res/= points.size();
  }
  
  return res.toPoint();
}



testqtuio::~testqtuio()
{}

#include "testqtuio.moc"
